==> mediawiki-1.12.1.tar.gz: mediawiki-1.12.1/languages/messages/MessagesTk.php <==
<?php
/** Turkmen (Türkmen)
 *
 * @ingroup Language
 * @file
 *
 * @author Flrn
 * @author Runningfridgesrule
 */

$messages = array(
# Dates
'sunday'        => 'Ýekşenbe',
'monday'        => 'Duşenbe',
'tuesday'       => 'Sişenbe',
'wednesday'     => 'Çarşenbe',
'thursday'      => 'Penşenbe',
'friday'        => 'Anna',
'saturday'      => 'Şenbe',
'sun'           => 'Dynç.',
'mon'           => 'Baş.',
'tue'           => 'Ýaş.',
'wed'           => 'Hoş.',
'thu'           => 'Sogap.',
'fri'           => 'Anna.',
'sat'           => 'Ruh.',
'january'       => 'ýanwar',
'february'      => 'fewral',
'march'         => 'mart',
'april'         => 'aprel',
'may_long'      => 'maý',
'june'          => 'iýun',
'july'          => 'iýul',
'august'        => 'awgust',
'september'     => 'sentýabr',
'october'       => 'oktýabr',
'november'      => 'noýabr',
'december'      => 'dekabr',
'january-gen'   => 'ýanwar',
'february-gen'  => 'fewral',
'march-gen'     => 'mart',
'april-gen'     => 'aprel',
'may-gen'       => 'maý',
'june-gen'      => 'iýun',
'july-gen'      => 'iýul',
'august-gen'    => 'awgust',
'september-gen' => 'sentýabr',
'october-gen'   => 'oktýabr',
'november-gen'  => 'noýabr',
'december-gen'  => 'dekabr',
'jan'           => 'ýan',
'feb'           => 'few',
'mar'           => 'mar',
'apr'           => 'apr',
'may'           => 'maý',
'jun'           => 'iýun',
'jul'           => 'iýul',
'aug'           => 'awg',
'sep'           => 'sen',
'oct'           => 'okt',
'nov'           => 'noý',
'dec'           => 'dek',

'newwindow' => '(täze bir penjirede açylyr)',
'mytalk'    => 'Tabşyryk sahypam',

'help'             => 'Ýardam',
'search'           => 'Gözle',
'searchbutton'     => 'Gözle',
'searcharticle'    => 'Git',
'permalink'        => 'Hemişelik aragatnaşyk',
'edit'             => 'Redakte',
'talkpagelinktext' => 'Çekisme',
'personaltools'    => 'Şahsy gurallar',
'talk'             => 'Çekisme',
'toolbox'          => 'Gurallar',
'redirectedfrom'   => '($1 sahypasyndan gönükdirildi)',
'jumptosearch'     => 'gözle',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'helppage' => 'Help:Içindäkiler',
'mainpage' => 'Baş Sahypa',
'privacy'  => 'Hususylyk ýörelgesi',

'editsection'     => 'redakte',
'editsectionhint' => '$1. bölümü redaktirle',
'showtoc'         => 'görkez',
'hidetoc'         => 'ýaşyr',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-category' => 'Kategoriya',

# General errors
'viewsource' => 'Gözbaşy gör',

# Login and logout pages
'userlogin'  => 'Sessiýa aç / täze hasap edin',
'userlogout' => 'Sessiýaýy kapas',

# Edit page toolbar
'bold_tip'        => 'Galyň ýazgy',
'italic_tip'      => 'Italik ýazgy',
'link_tip'        => 'Iç aragatnaşyk',
'extlink_sample'  => 'http://www.example.com aragatnaşyk suratlandyrmasy',
'extlink_tip'     => 'Daş aragatnaşyk (Adresiň öňüňe http:// goýmaýy unutma)',
'headline_sample' => 'Sözbaşy ýazgysy',

# Edit pages
'minoredit' => 'Bu bir kiçi özgertiş',
'showdiff'  => 'Özgertişleriňi görkez',

# History pages
'cur'  => 'parh',
'last' => 'soň',

# Search results
'powersearch' => 'Giňişleýin Gözleg',

# Recent changes
'recentchanges'   => 'Ahyrky özgertişler',
'rcshowhideminor' => '$1 kiçi özgerişik',
'hist'            => 'geçmiş',
'hide'            => 'Ýaşyr',
'minoreditletter' => 'k',
'newpageletter'   => 'T',
'boteditletter'   => 'b',

# Recent changes linked
'recentchangeslinked' => 'Meňzeçli özgertişler',

# Image list
'filehist-current'  => 'häzirki',
'filehist-datetime' => 'Gün/Zaman',
'filehist-user'     => 'Ulanyjy',
'imagelinks'        => 'Aragatnaşyklar',

# Miscellaneous special pages
'specialpages' => 'Yörite sahypalar',
'move'         => 'Atyňy özgert',

# Special:Allpages
'allpagessubmit' => 'Git',

# Namespace form on various pages
'blanknamespace' => '(Baş)',

# Contributions
'mycontris' => 'Goşantlarım',

# What links here
'whatlinkshere'       => 'Sahypaýa aragatnaşyklar',
'isredirect'          => 'gönükdirme sahypasy',
'whatlinkshere-links' => '← aragatnaşyklar',

# Block/unblock
'blocklink' => 'bökdençle',

# Move page
'1movedto2' => '[[$1]] sahypasy [[$2]] sahypasyna göçürildi',

# Thumbnails
'thumbnail-more' => 'Ulal',

# Tooltip help for the actions
'tooltip-pt-userpage'       => 'Menim ulanyjy sahypam',
'tooltip-pt-mytalk'         => 'Menim tabşyryk sahypam',
'tooltip-pt-mycontris'      => 'Ýasadyýym goşantlarımıň tablisasy',
'tooltip-pt-logout'         => 'Sessiýaýy kapas',
'tooltip-ca-move'           => 'Bu sahypanyň atyňy özgert',
'tooltip-ca-nstab-category' => 'Kategoriya sahypsayny gör',

);

==> mediawiki-1.13.1.tar.gz: mediawiki-1.13.1/languages/messages/MessagesTk.php <==
<?php
/** Turkmen (Türkmen)
 *
 * @ingroup Language
 * @file
 *
 * @author Flrn
 * @author Runningfridgesrule
 */

$messages = array(
# Dates
'sunday'        => 'Ýekşenbe',
'monday'        => 'Duşenbe',
'tuesday'       => 'Sişenbe',
'wednesday'     => 'Çarşenbe',
'thursday'      => 'Penşenbe',
'friday'        => 'Anna',
'saturday'      => 'Şenbe',
'sun'           => 'Dynç.',
'mon'           => 'Baş.',
'tue'           => 'Ýaş.',
'wed'           => 'Hoş.',
'thu'           => 'Sogap.',
'fri'           => 'Anna.',
'sat'           => 'Ruh.',
'january'       => 'ýanwar',
'february'      => 'fewral',
'march'         => 'mart',
'april'         => 'aprel',
'may_long'      => 'maý',
'june'          => 'iýun',
'july'          => 'iýul',
'august'        => 'awgust',
'september'     => 'sentýabr',
'october'       => 'oktýabr',
'november'      => 'noýabr',
'december'      => 'dekabr',
'january-gen'   => 'ýanwar',
'february-gen'  => 'fewral',
'march-gen'     => 'mart',
'april-gen'     => 'aprel',
'may-gen'       => 'maý',
'june-gen'      => 'iýun',
'july-gen'      => 'iýul',
'august-gen'    => 'awgust',
'september-gen' => 'sentýabr',
'october-gen'   => 'oktýabr',
'november-gen'  => 'noýabr',
'december-gen'  => 'dekabr',
'jan'           => 'ýan',
'feb'           => 'few',
'mar'           => 'mar',
'apr'           => 'apr',
'may'           => 'maý',
'jun'           => 'iýun',
'jul'           => 'iýul',
'aug'           => 'awg',
'sep'           => 'sen',
'oct'           => 'okt',
'nov'           => 'noý',
'dec'           => 'dek',

'newwindow' => '(täze bir penjirede açylyr)',
'mytalk'    => 'Tabşyryk sahypam',

'help'             => 'Ýardam',
'search'           => 'Gözle',
'searchbutton'     => 'Gözle',
'searcharticle'    => 'Git',
'permalink'        => 'Hemişelik aragatnaşyk',
'edit'             => 'Redakte',
'talkpagelinktext' => 'Çekisme',
'personaltools'    => 'Şahsy gurallar',
'talk'             => 'Çekisme',
'toolbox'          => 'Gurallar',
'redirectedfrom'   => '($1 sahypasyndan gönükdirildi)',
'jumptosearch'     => 'gözle',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'helppage'             => 'Help:Içindäkiler',
'mainpage'             => 'Baş Sahypa',
'mainpage-description' => 'Baş Sahypa',
'privacy'              => 'Hususylyk ýörelgesi',

'editsection'     => 'redakte',
'editsectionhint' => '$1. bölümü redaktirle',
'showtoc'         => 'görkez',
'hidetoc'         => 'ýaşyr',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-category' => 'Kategoriya',

# General errors
'viewsource' => 'Gözbaşy gör',

# Login and logout pages
'nav-login-createaccount' => 'Sessiýa aç / täze hasap edin',
'userlogin'               => 'Sessiýa aç / täze hasap edin',
'userlogout'              => 'Sessiýaýy kapas',

# Edit page toolbar
'bold_tip'        => 'Galyň ýazgy',
'italic_tip'      => 'Italik ýazgy',
'link_tip'        => 'Iç aragatnaşyk',
'extlink_sample'  => 'http://www.example.com aragatnaşyk suratlandyrmasy',
'extlink_tip'     => 'Daş aragatnaşyk (Adresiň öňüňe http:// goýmaýy unutma)',
'headline_sample' => 'Sözbaşy ýazgysy',

# Edit pages
'minoredit' => 'Bu bir kiçi özgertiş',
'showdiff'  => 'Özgertişleriňi görkez',

# History pages
'cur'  => 'parh',
'last' => 'soň',

# Search results
'powersearch' => 'Giňişleýin Gözleg',

# Recent changes
'recentchanges'   => 'Ahyrky özgertişler',
'rcshowhideminor' => '$1 kiçi özgerişik',
'hist'            => 'geçmiş',
'hide'            => 'Ýaşyr',
'minoreditletter' => 'k',
'newpageletter'   => 'T',
'boteditletter'   => 'b',

# Recent changes linked
'recentchangeslinked' => 'Meňzeçli özgertişler',

# Image description page
'filehist-current'  => 'häzirki',
'filehist-datetime' => 'Gün/Zaman',
'filehist-user'     => 'Ulanyjy',
'imagelinks'        => 'Aragatnaşyklar',

# Miscellaneous special pages
'move' => 'Atyňy özgert',

# Special:AllPages
'allpagessubmit' => 'Git',

# Namespace form on various pages
'blanknamespace' => '(Baş)',

# Contributions
'mycontris' => 'Goşantlarım',

# What links here
'whatlinkshere'       => 'Sahypaýa aragatnaşyklar',
'isredirect'          => 'gönükdirme sahypasy',
'whatlinkshere-links' => '← aragatnaşyklar',

# Block/unblock
'blocklink' => 'bökdençle',

# Move page
'1movedto2' => '[[$1]] sahypasy [[$2]] sahypasyna göçürildi',

# Thumbnails
'thumbnail-more' => 'Ulal',

# Tooltip help for the actions
'tooltip-pt-userpage'       => 'Menim ulanyjy sahypam',
'tooltip-pt-mytalk'         => 'Menim tabşyryk sahypam',
'tooltip-pt-mycontris'      => 'Ýasadyýym goşantlarımıň tablisasy',
'tooltip-pt-logout'         => 'Sessiýaýy kapas',
'tooltip-ca-move'           => 'Bu sahypanyň atyňy özgert',
'tooltip-ca-nstab-category' => 'Kategoriya sahypsayny gör',

# Special:SpecialPages
'specialpages' => 'Yörite sahypalar',

);
